==> cbpManager_1.2.2.zip: cbpManager/NEWS.md <==
# Bugfixes:

* cbpManager 1.2.2 & cbpManager 1.3.2 (Nov 11, 2021):
  - Fixed crash when trying to add a custom timeline track without selecting the type of the track.
  - Fixed Error preventing editing first 3 special rows of patient and sample tab table.
  - New added patients & samples are now at the top of the patient & sample tab tables.
  - Fixed bug preventing editing of treatment timeline data when TREATMENT_TYPE or SUBTYPE were not provided.
  - Fixed bug preventing editing the date of first diagnosis of a patient.

* cbpManager 1.2.1 & cbpManager 1.3.1 (Nov 11, 2021):
  - Show cbpManager version
  - Minor bugfixes

* cbpManager 1.1.2 & cbpManager 1.0.2 (Aug 4, 2021):
  - Prevent changing PATIENT_ID / SAMPLE_ID to an existing one when editing a patient / sample.

* cbpManager 1.1.1 & cbpManager 1.0.1 (Jul 19, 2021):
  - Show only directories instead of files and directories in the study selection
  - Added notifications if no study is loaded but the user tries to push buttons
  - Resolved error when trying to add a new column in the Sample tab

# New features cbpManager 1.3.2

* Oncotree functionality is now avaliable also in the sample tab 

# New features cbpManager 0.1.1

* 'Validation' tab allows to validate created files.
* Improved usability by changing descriptions and adding interactive tours

# New features cbpManager 0.1.0

* much of the functionality available, in a proof of concept format.

# New features cbpManager 0.0.1

* backbone of the project started!

==> cbpManager_1.6.0.zip: cbpManager/NEWS.md <==
# Bugfixes:

* cbpManager 1.2.2 & cbpManager 1.3.2 (Nov 11, 2021):
  - Fixed crash when trying to add a custom timeline track without selecting the type of the track.
  - Fixed Error preventing editing first 3 special rows of patient and sample tab table.
  - New added patients & samples are now at the top of the patient & sample tab tables.
  - Fixed bug preventing editing of treatment timeline data when TREATMENT_TYPE or SUBTYPE were not provided.
  - Fixed bug preventing editing the date of first diagnosis of a patient.

* cbpManager 1.2.1 & cbpManager 1.3.1 (Nov 11, 2021):
  - Show cbpManager version
  - Minor bugfixes

* cbpManager 1.1.2 & cbpManager 1.0.2 (Aug 4, 2021):
  - Prevent changing PATIENT_ID / SAMPLE_ID to an existing one when editing a patient / sample.

* cbpManager 1.1.1 & cbpManager 1.0.1 (Jul 19, 2021):
  - Show only directories instead of files and directories in the study selection
  - Added notifications if no study is loaded but the user tries to push buttons
  - Resolved error when trying to add a new column in the Sample tab

# New features cbpManager 1.3.2

* Oncotree functionality is now avaliable also in the sample tab.
* Major modifications of the Mutation tab. Mutation data is now editable.

# New features cbpManager 0.1.1

* 'Validation' tab allows to validate created files.
* Improved usability by changing descriptions and adding interactive tours

# New features cbpManager 0.1.0

* much of the functionality available, in a proof of concept format.

# New features cbpManager 0.0.1

* backbone of the project started!
